pypret.material module
======================

.. automodule:: pypret.material
    :no-members:

Available materials
-------------------
.. autodata:: pypret.material.BK7
.. autodata:: pypret.material.FS

Base classes
------------
.. autoclass:: pypret.material.BaseMaterial
.. autoclass:: pypret.material.SellmeierF1
.. autoclass:: pypret.material.SellmeierF2

